PyWebRerport

# 50.00%

rate of pass

- Pass 5
- Fail 4
- Warning 1
- Skip 1

Good Report

is a tool of productivity

##### Pass

5
P

50.00% Case been passed

##### Fail

4
F

40.00% Case been failed

##### Warning

1
W

10.00% Just warning

##### Skip

1
S

10.00% Case been skiped

### Results Preview

TEST name | Counts | Running time | Pass Rate
--- | --- | --- | ---
test/testsuites/pytest/test_ddt.py | 2 | 0.001 | 50.00%
test/testsuites/pytest/test_fail.py | 3 | 0.001 | 0.00%
test/testsuites/pytest/test_success.py | 5 | 0.0 | 80.00%

### Total of testig

Type | Number |
--- | --- | ---
Admin | 1,480 | 60%
Role | 5,480 | 70%
Pay | 4,807 | 80%
Service | 3,678 | 75%
Performance | 2,645 | 30%

### Results Preview

Case name | Class name | Duration | Status
--- | --- | --- | ---
test_case1[1+2-2] | Testddt | 0.001 | failed
test_case1[3+5-8] | Testddt | 0.0 | passed
test_case1 | TestC | 0.0 | failed
test_case2 | TestC | 0.0 | failed
test_case3 | TestC | 0.001 | failed
test_case1 | TestA | 0.0 | passed
test_case2 | TestA | 0.0 | passed
test_print | TestA | 0.0 | passed
test_case3 | TestB | 0.0 | skipped
test_err_print | TestB | 0.0 | passed

pass
test_case1
Information
start_time: xxx
duration: xxx
Description
Lorem ipsum dolor sit amet consectetur adipisicing elit. Fuga impedit facere, itaque, amet, error accusantium nam ducimus reiciendis incidunt quis similique! Accusantium provident sint voluptate tempora? Soluta beatae ea repudiandae?
Execution
Lorem ipsum dolor sit amet.